#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-JODGftKAoTu6YA9szsKg7W
key:                  gitit-0.15.1.2-JODGftKAoTu6YA9szsKg7W
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  0de275c92ff58ba536f06c3004b373d6
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-JODGftKAoTu6YA9szsKg7W
depends:
    HStringTemplate-0.8.8-FV31iPCuEmY7hKMvULtXcZ
    HTTP-4000.4.1-ImfsOiouyIW6aWF3qVzMZy
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW base-4.18.2.1
    base64-bytestring-1.2.1.0-6zbb0o9xH9hLkYSzTxgmy9
    blaze-html-0.9.2.0-BrSAzNVQiYJEXfJmmg87r5 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-xZB2gwaSK33AP5NbkMsEU
    feed-1.3.2.1-IjiCM6mmxSAGMWOBTBuH9C filepath-1.4.300.1
    filestore-0.6.5.1-4Ts75p8WHlaDcThuSU1HWN ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-5zFqxT39yLRC3jIVUw8b93
    hoauth2-2.14.0-CX3nBjX0mzUGfPw9yezCD2
    hslogger-1.3.2.0-KmFS0a6yWOl4ae8UKJbs1U
    http-client-tls-0.3.6.4-9KaGRUfQlOcH11qQFZ8oLV
    http-conduit-2.3.9.1-1jgAUVyqkxJ6z3Pvba5xG2
    json-0.10-Ix3cJnfMrt84nrYZAgyGJ mtl-2.3.1
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP
    network-bsd-2.8.1.0-HmytFZCsuo78cEEETdsQll
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-1DKE0x92VRa5b3GF6kWKcy
    pandoc-types-1.23.1-7wbk8RCvTUWIER9yMXo060 parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    recaptcha-0.1.0.4-9zbBpMzYBxX7kIPyzXiMxF
    safe-0.3.21-9fS1HagXWSs3bwv9EfXX3u
    skylighting-0.14.4-5V3tkjFrZiA7DosKil5FiP
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-GhxEKVO9aRZHddME5iK0hL
    tagsoup-0.14.8-EUJgnzyeT340o0wxyvxVK
    temporary-1.3-imd8AcD6Pg3Lf1V6ZsYLS text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-1Y3f0a6vm2iHD6EBaK8nm3
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-Jof6vDanUQb75njnp02bo5 xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-9O7VQbNwRmb985lnsjzGmX
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-9ToyWsRtsL78Ze5ujGxizW
    zlib-0.7.0.0-4R5icK1yXLI4HdJUCaGWsH

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

